@@ -42,13 +42,6 @@
 #include "timezonerule.h"
 
 #include <config-kstars.h>
-
-#ifdef HAVE_INDI_H
-#include "indi/indidriver.h"
-#include "lilxml.h"
-#include "indi/indistd.h"
-#endif
-
 #include "dialogs/detaildialog.h"
 
 namespace {
@@ -124,6 +117,7 @@ KStarsData::KStarsData() :
     m_logObject = new OAL::Log;
     // at startup times run forward
     setTimeDirection( 0.0 );
+
 }
 
 KStarsData::~KStarsData() {
@@ -134,9 +128,6 @@ KStarsData::~KStarsData() {
     delete m_logObject;
 
     qDeleteAll( geoList );
-#ifdef HAVE_INDI_H
-    qDeleteAll( INDIHostsList );
-#endif
     qDeleteAll( ADVtreeList );
 
     pinstance = 0;
@@ -172,7 +163,6 @@ bool KStarsData::initialize() {
         return false;
 
     emit progressText( i18n("Loading Variable Stars" ) );
-    readINDIHosts();
     readUserLog();
     readADVTreeData();
 
@@ -731,75 +721,6 @@ bool KStarsData::readADVTreeData()
     return true;
 }
 
-bool KStarsData::readINDIHosts()
-{
-#ifdef HAVE_INDI_H
-    QString indiFile("indihosts.xml");
-    QFile localeFile;
-    QFile file;
-    char errmsg[1024];
-    char c;
-    LilXML *xmlParser = newLilXML();
-    XMLEle *root = NULL;
-    XMLAtt *ap;
-
-    file.setFileName( KStandardDirs::locate( "appdata", indiFile ) );
-    if ( file.fileName().isEmpty() || !file.open( QIODevice::ReadOnly ) )
-        return false;
-
-    while ( file.getChar( &c ) )
-    {
-        root = readXMLEle(xmlParser, c, errmsg);
-
-        if (root)
-        {
-            // Get host name
-            ap = findXMLAtt(root, "name");
-            if (!ap) {
-                delLilXML(xmlParser);
-                return false;
-            }
-
-            INDIHostsInfo *VInfo = new INDIHostsInfo;
-            VInfo->name = QString(valuXMLAtt(ap));
-
-            // Get host name
-            ap = findXMLAtt(root, "hostname");
-
-            if (!ap) {
-                delete VInfo;
-                delLilXML(xmlParser);
-                return false;
-            }
-
-            VInfo->hostname = QString(valuXMLAtt(ap));
-            ap = findXMLAtt(root, "port");
-
-            if (!ap) {
-                delete VInfo;
-                delLilXML(xmlParser);
-                return false;
-            }
-
-            VInfo->portnumber = QString(valuXMLAtt(ap));
-            VInfo->isConnected = false;
-            VInfo->deviceManager = NULL;
-            INDIHostsList.append(VInfo);
-
-            delXMLEle(root);
-        }
-        else if (errmsg[0])
-            kDebug() << errmsg;
-    }
-
-    delLilXML(xmlParser);
-
-    return true;
-    #else
-    return false;
-    #endif
-}
-
 //There's a lot of code duplication here, but it's not avoidable because 
 //this function is only called from main.cpp when the user is using 
 //"dump" mode to produce an image from the command line.  In this mode, 
@@ -981,7 +902,7 @@ bool KStarsData::executeScript( const QString &scriptname, SkyMap *map ) {
                     .subs( hr ).subs( mnt ).subs( sec ).toString() << endl;
                 }
             } else if ( fn[0] == "changeViewOption" && fn.size() == 3 ) {
-                bool bOk(false), nOk(false), dOk(false);
+                bool bOk(false), dOk(false);
 
                 //parse bool value
                 bool bVal(false);
@@ -990,9 +911,6 @@ bool KStarsData::executeScript( const QString &scriptname, SkyMap *map ) {
                 if ( fn[2] == "1" ) { bOk = true; bVal = true; }
                 if ( fn[2] == "0" ) { bOk = true; bVal = false; }
 
-                //parse int value
-                int nVal = fn[2].toInt( &nOk );
-
                 //parse double value
                 double dVal = fn[2].toDouble( &dOk );
 
